@@ -26,9 +26,8 @@ class PromptToolkitCompleter(Completer):
     def get_completions(self, document, complete_event):
         """Returns a generator for list of completions."""
         env = builtins.__xonsh_env__
-        should_complete = (
-            complete_event.completion_requested or
-            env.get('UPDATE_COMPLETIONS_ON_KEYPRESS')
+        should_complete = complete_event.completion_requested or env.get(
+            "UPDATE_COMPLETIONS_ON_KEYPRESS"
         )
         #  Only generate completions when the user hits tab.
         if not should_complete or self.completer is None:
@@ -38,18 +37,16 @@ class PromptToolkitCompleter(Completer):
         line_ex = builtins.aliases.expand_alias(line)
 
         endidx = document.cursor_position_col
-        begidx = (line[:endidx].rfind(' ') + 1
-                  if line[:endidx].rfind(' ') >= 0 else 0)
+        begidx = line[:endidx].rfind(" ") + 1 if line[:endidx].rfind(" ") >= 0 else 0
         prefix = line[begidx:endidx]
         expand_offset = len(line_ex) - len(line)
         # get normal completions
-        completions, l = self.completer.complete(prefix, line_ex,
-                                                 begidx + expand_offset,
-                                                 endidx + expand_offset,
-                                                 self.ctx)
+        completions, l = self.completer.complete(
+            prefix, line_ex, begidx + expand_offset, endidx + expand_offset, self.ctx
+        )
         # completions from auto suggest
         sug_comp = None
-        if env.get('AUTO_SUGGEST') and env.get('AUTO_SUGGEST_IN_COMPLETIONS'):
+        if env.get("AUTO_SUGGEST") and env.get("AUTO_SUGGEST_IN_COMPLETIONS"):
             sug_comp = self.suggestion_completion(document, line)
             if sug_comp is None:
                 pass
@@ -65,10 +62,10 @@ class PromptToolkitCompleter(Completer):
         elif len(os.path.commonprefix(completions)) <= len(prefix):
             self.reserve_space()
         # Find common prefix (strip quoting)
-        c_prefix = os.path.commonprefix([a.strip('\'"') for a in completions])
+        c_prefix = os.path.commonprefix([a.strip("'\"") for a in completions])
         # Find last split symbol, do not trim the last part
         while c_prefix:
-            if c_prefix[-1] in r'/\.:@,':
+            if c_prefix[-1] in r"/\.:@,":
                 break
             c_prefix = c_prefix[:-1]
         # yield completions
@@ -78,7 +75,7 @@ class PromptToolkitCompleter(Completer):
             pre = len(c_prefix)
         for comp in completions:
             # do not display quote
-            disp = comp[pre:].strip('\'"')
+            disp = comp[pre:].strip("'\"")
             yield Completion(comp, -l, display=disp)
 
     def suggestion_completion(self, document, line):
@@ -87,8 +84,8 @@ class PromptToolkitCompleter(Completer):
         sug = self.hist_suggester.get_suggestion(app.current_buffer, document)
         if sug is None:
             return None
-        comp, _, _ = sug.text.partition(' ')
-        _, _, prev = line.rpartition(' ')
+        comp, _, _ = sug.text.partition(" ")
+        _, _, prev = line.rpartition(" ")
         return prev + comp
 
     def reserve_space(self):
@@ -99,7 +96,7 @@ class PromptToolkitCompleter(Completer):
 
         if window and window.render_info:
             h = window.render_info.content_height
-            r = builtins.__xonsh_env__.get('COMPLETIONS_MENU_ROWS')
+            r = builtins.__xonsh_env__.get("COMPLETIONS_MENU_ROWS")
             size = h + r
             last_h = render._last_screen.height if render._last_screen else 0
             last_h = max(render._min_available_height, last_h)
